@@ -1,7 +1,9 @@
 //! This module provides functionalities for
 //! manipulating the actual Document Object Model in the browser
 //!
+mod application;
 pub mod apply_patches;
+mod callback;
 pub mod cmd;
 mod component;
 mod created_node;
@@ -13,7 +15,9 @@ mod program;
 mod util;
 mod window;
 
-pub use component::{Application, Component, Measurements, Widget};
+pub use application::{Application, Measurements};
+pub use callback::Callback;
+pub use component::{Component, Container, Effects, View};
 pub use created_node::CreatedNode;
 pub use dispatch::Dispatch;
 pub use dom_updater::DomUpdater;
@@ -21,8 +25,7 @@ pub use events::*;
 pub use http::Http;
 pub use program::Program;
 pub use util::{
-    body, document, execute_in_request_animation_frame, history, now,
-    performance, request_animation_frame, window,
+    body, document, history, now, performance, request_animation_frame, window,
 };
 pub use window::Window;
 
