@@ -145,7 +145,7 @@ fn find_all_nodes_by_path(
 
 /// Get the "data-sauron-vdom-id" of all the desendent of this node including itself
 /// This is needed to free-up the closure that was attached ActiveClosure manually
-fn get_node_descendant_data_vdom_id(root_element: &Element) -> Vec<u32> {
+fn get_node_descendant_data_vdom_id(root_element: &Element) -> Vec<usize> {
     let mut data_vdom_id = vec![];
 
     // TODO: there should be a better way to get the node-id back
@@ -154,7 +154,7 @@ fn get_node_descendant_data_vdom_id(root_element: &Element) -> Vec<u32> {
         root_element.get_attribute(created_node::DATA_VDOM_ID)
     {
         let vdom_id = vdom_id_str
-            .parse::<u32>()
+            .parse::<usize>()
             .expect("unable to parse sauron_vdom-id");
         data_vdom_id.push(vdom_id);
     }
@@ -163,7 +163,7 @@ fn get_node_descendant_data_vdom_id(root_element: &Element) -> Vec<u32> {
     let child_node_count = children.length();
     for i in 0..child_node_count {
         let child_node = children.item(i).expect("Expecting a child node");
-        if let Node::ELEMENT_NODE = child_node.node_type() {
+        if child_node.node_type() == Node::ELEMENT_NODE {
             let child_element = child_node.unchecked_ref::<Element>();
             let child_data_vdom_id =
                 get_node_descendant_data_vdom_id(child_element);
@@ -239,6 +239,7 @@ fn remove_event_listener_with_name(
 ///
 /// Note: a mutable root_node is passed here
 /// for the sole purpose of setting it when the a patch ReplaceNode at 0 is encountered.
+#[track_caller]
 fn apply_patch_to_node<DSP, MSG>(
     program: &DSP,
     root_node: &mut Node,
@@ -355,7 +356,7 @@ where
                 }
             }
 
-            if element.node_type() != Node::TEXT_NODE {
+            if element.node_type() == Node::ELEMENT_NODE {
                 remove_event_listeners(element, old_closures)?;
             }
             element
@@ -375,16 +376,12 @@ where
             let element: &Element = node.unchecked_ref();
             let parent_node =
                 element.parent_node().expect("must have a parent node");
-            if element.node_type() == Node::COMMENT_NODE {
-                //do not remove comment nodes
-            } else {
-                parent_node
-                    .remove_child(element)
-                    .expect("must remove target node");
-                if element.node_type() != Node::TEXT_NODE {
-                    let element: &Element = node.unchecked_ref();
-                    remove_event_listeners(element, old_closures)?;
-                }
+            parent_node
+                .remove_child(element)
+                .expect("must remove target node");
+            if element.node_type() == Node::ELEMENT_NODE {
+                let element: &Element = node.unchecked_ref();
+                remove_event_listeners(element, old_closures)?;
             }
             Ok(active_closures)
         }
@@ -410,5 +407,9 @@ where
             node.set_node_value(Some(&ct.new.text));
             Ok(active_closures)
         }
+        Patch::ChangeComment(cm) => {
+            node.set_node_value(Some(&cm.new));
+            Ok(active_closures)
+        }
     }
 }
