@@ -1,3 +1,5 @@
+use crate::dom::cmd::Modifier;
+
 /// Effects are a way for component to execute subsequent updates based on certain conditions.
 /// This can be used for doing animation and incremental changes to the view to provide an effect
 /// of transition or animation.
@@ -5,18 +7,23 @@
 /// Effects contains 2 types of Messages. The local messages which will be executed in its
 /// own component on the next update loop. The other type is the external effects which are Messages
 /// that are sent to the parent Component in response to an event that has been triggerred.
-pub struct Effects<MSG, PMSG> {
+pub struct Effects<MSG, XMSG> {
     /// Messages that will be executed locally in the Component
     pub local: Vec<MSG>,
     /// effects that will be executed on the parent Component that instantiate
     /// this component
-    pub external: Vec<PMSG>,
+    pub external: Vec<XMSG>,
+    pub(crate) modifier: Modifier,
 }
 
-impl<MSG, PMSG> Effects<MSG, PMSG> {
+impl<MSG, XMSG> Effects<MSG, XMSG> {
     /// create a new Effects with local and external expects respectively
-    pub fn new(local: Vec<MSG>, external: Vec<PMSG>) -> Self {
-        Self { local, external }
+    pub fn new(local: Vec<MSG>, external: Vec<XMSG>) -> Self {
+        Self {
+            local,
+            external,
+            modifier: Modifier::default(),
+        }
     }
 
     /// Create an Effects with  local messages that will be executed on the next update loop on this Component
@@ -24,13 +31,15 @@ impl<MSG, PMSG> Effects<MSG, PMSG> {
         Self {
             local,
             external: vec![],
+            modifier: Modifier::default(),
         }
     }
     /// Create an Effects with extern messages that will be executed on the parent Component
-    pub fn with_external(external: Vec<PMSG>) -> Self {
+    pub fn with_external(external: Vec<XMSG>) -> Self {
         Self {
             local: vec![],
             external,
+            modifier: Modifier::default(),
         }
     }
 
@@ -39,6 +48,7 @@ impl<MSG, PMSG> Effects<MSG, PMSG> {
         Self {
             local: vec![],
             external: vec![],
+            modifier: Modifier::default(),
         }
     }
 
@@ -46,15 +56,20 @@ impl<MSG, PMSG> Effects<MSG, PMSG> {
     /// MSG2 with the use of the mapping function `f`.
     ///
     /// The external messages stays the same.
-    pub fn map_msg<F, MSG2>(self, f: F) -> Effects<MSG2, PMSG>
+    pub fn map_msg<F, MSG2>(self, f: F) -> Effects<MSG2, XMSG>
     where
         F: Fn(MSG) -> MSG2 + 'static,
     {
-        let Effects { local, external } = self;
+        let Effects {
+            local,
+            external,
+            modifier,
+        } = self;
 
         Effects {
             local: local.into_iter().map(f).collect(),
             external,
+            modifier,
         }
     }
 
@@ -62,11 +77,15 @@ impl<MSG, PMSG> Effects<MSG, PMSG> {
     /// and mapping them with function `f` such that they can be of the same type as local effects
     /// them merge them together into local effects.
     ///
-    pub fn localize<F>(self, f: F) -> Effects<PMSG, ()>
+    pub fn localize<F>(self, f: F) -> Effects<XMSG, ()>
     where
-        F: Fn(MSG) -> PMSG + 'static,
+        F: Fn(MSG) -> XMSG + 'static,
     {
-        let Effects { local, external } = self;
+        let Effects {
+            local,
+            external,
+            modifier,
+        } = self;
 
         Effects {
             local: external
@@ -74,6 +93,7 @@ impl<MSG, PMSG> Effects<MSG, PMSG> {
                 .chain(local.into_iter().map(f))
                 .collect(),
             external: vec![],
+            modifier,
         }
     }
 
@@ -82,4 +102,16 @@ impl<MSG, PMSG> Effects<MSG, PMSG> {
         self.local.extend(local);
         self
     }
+
+    /// Modify the Effect such that it will not do an update on the view when it is executed
+    pub fn no_render(mut self) -> Self {
+        self.modifier.should_update_view = false;
+        self
+    }
+
+    /// Modify the Effect such that it will log measurement when it is executed
+    pub fn measure(mut self) -> Self {
+        self.modifier.log_measurements = true;
+        self
+    }
 }
