@@ -6,28 +6,28 @@ use crate::{
     html::attributes::{AttributeValue, SegregatedAttributes, Special},
     Attribute, Event,
 };
-use once_cell::sync::OnceCell;
-use std::{collections::HashMap, sync::Mutex};
+use std::cell::Cell;
+use std::collections::HashMap;
 use wasm_bindgen::{closure::Closure, JsCast, JsValue};
 use web_sys::{
     self, Element, EventTarget, HtmlElement, HtmlInputElement,
     HtmlTextAreaElement, Node, Text,
 };
 
+thread_local!(static NODE_ID_COUNTER: Cell<usize> = Cell::new(1));
+
 /// This is the value of the data-sauron-vdom-id.
 /// Used to uniquely identify elements that contain closures so that the DomUpdater can
 /// look them up by their unique id.
 /// When the DomUpdater sees that the element no longer exists it will drop all of it's
 /// Rc'd Closures for those events.
-static DATA_SAURON_VDOM_ID_VALUE: OnceCell<Mutex<u32>> = OnceCell::new();
-
-fn create_unique_identifier() -> u32 {
-    let mut elem_unique_id = DATA_SAURON_VDOM_ID_VALUE
-        .get_or_init(|| Mutex::new(0))
-        .lock()
-        .expect("Unable to obtain lock");
-    *elem_unique_id += 1;
-    *elem_unique_id
+fn create_unique_identifier() -> usize {
+    let id = NODE_ID_COUNTER.with(|x| {
+        let tmp = x.get();
+        x.set(tmp + 1);
+        tmp
+    });
+    id
 }
 
 pub(crate) const DATA_VDOM_ID: &str = "data-vdom-id";
@@ -39,7 +39,7 @@ pub(crate) const DATA_VDOM_ID: &str = "data-vdom-id";
 /// attached to.
 ///
 pub type ActiveClosure =
-    HashMap<u32, Vec<(&'static str, Closure<dyn FnMut(web_sys::Event)>)>>;
+    HashMap<usize, Vec<(&'static str, Closure<dyn FnMut(web_sys::Event)>)>>;
 
 /// A node along with all of the closures that were created for that
 /// node's events and all of it's child node's events.
@@ -80,6 +80,10 @@ impl CreatedNode {
                 let text_node = Self::create_text_node(&txt.text);
                 CreatedNode::without_closures(text_node.unchecked_into())
             }
+            crate::Node::Comment(comment) => {
+                let comment_node = crate::document().create_comment(comment);
+                CreatedNode::without_closures(comment_node.unchecked_into())
+            }
             crate::Node::Element(element_node) => {
                 Self::create_element_node(program, element_node, focused_node)
             }
@@ -139,6 +143,7 @@ impl CreatedNode {
         if velem.is_focused() {
             *focused_node = Some(element.clone().unchecked_into());
             log::trace!("element is focused..{:?}", focused_node);
+            Self::set_element_focus(&element);
         }
 
         let mut closures = ActiveClosure::new();
@@ -150,51 +155,21 @@ impl CreatedNode {
             &velem.get_attributes().iter().collect::<Vec<_>>(),
         );
 
-        let mut previous_node_was_text = false;
-
         for child in velem.get_children().iter() {
-            match child {
-                crate::Node::Text(txt) => {
-                    let current_node: &web_sys::Node = element.as_ref();
+            if child.is_safe_html() {
+                let child_text = child.unwrap_text();
+                // https://developer.mozilla.org/en-US/docs/Web/API/Element/insertAdjacentHTML
+                element
+                    .insert_adjacent_html("beforeend", &child_text.text)
+                    .expect("must not error");
+            } else {
+                let created_child =
+                    Self::create_dom_node(program, child, focused_node);
 
-                    // We ensure that the text siblings are patched by preventing the browser from merging
-                    // neighboring text nodes. Originally inspired by some of React's work from 2016.
-                    //  -> https://reactjs.org/blog/2016/04/07/react-v15.html#major-changes
-                    //  -> https://github.com/facebook/react/pull/5753
-                    //
-                    // `mordor` one does not simply walk into mordor
-                    if previous_node_was_text {
-                        let separator = document.create_comment("mordor");
-                        current_node
-                            .append_child(separator.as_ref())
-                            .expect("Unable to append child");
-                    }
-
-                    if txt.safe_html {
-                        // https://developer.mozilla.org/en-US/docs/Web/API/Element/insertAdjacentHTML
-                        element
-                            .insert_adjacent_html("beforeend", &txt.text)
-                            .expect("must not error");
-                    } else {
-                        let text_node = Self::create_text_node(&txt.text);
-                        current_node
-                            .append_child(&text_node)
-                            .expect("Unable to append text node");
-                    }
-
-                    previous_node_was_text = true;
-                }
-                crate::Node::Element(_element_node) => {
-                    previous_node_was_text = false;
-
-                    let created_child =
-                        Self::create_dom_node(program, child, focused_node);
-                    closures.extend(created_child.closures);
-
-                    element
-                        .append_child(&created_child.node)
-                        .expect("Unable to append element node");
-                }
+                closures.extend(created_child.closures);
+                element
+                    .append_child(&created_child.node)
+                    .expect("Unable to append element node");
             }
         }
 
