@@ -1,6 +1,6 @@
 //! Provides functions and macros to build html elements
 use crate::{Attribute, Node};
-pub use mt_dom::{element, element_ns, safe_html, text};
+pub use mt_dom::{comment, element, element_ns, safe_html, text};
 
 #[macro_use]
 pub mod attributes;
@@ -28,7 +28,7 @@ pub fn view_if<MSG>(flag: bool, node: Node<MSG>) -> Node<MSG> {
     if flag {
         node
     } else {
-        span(vec![], vec![])
+        comment("hidden")
     }
 }
 
