@@ -55,7 +55,7 @@ macro_rules! declare_common_svg_tags_and_macro {
         }
 
 
-        #[cfg(feature = "with-parser")]
+        #[cfg(feature = "with-lookup")]
         /// These are the commonly used svg tags such as rect, circle, path, arc, ..etc.
         pub const SVG_TAGS: [&'static str; 66] = [ $(stringify!($name),)* ];
 
@@ -73,7 +73,7 @@ macro_rules! declare_svg_tags_special{
      ) => {
         declare_svg_tags!{ $($name=>$attribute;)*}
 
-        #[cfg(feature = "with-parser")]
+        #[cfg(feature = "with-lookup")]
         /// These are svg tags which the tags are non proper rust identifier, so they are handled
         /// differently
         pub const SVG_TAGS_SPECIAL:[(&'static str,&'static str); 2] = [$((stringify!($name),$attribute),)*];
@@ -89,7 +89,7 @@ macro_rules! declare_svg_tags_non_common{
      ) => {
         declare_svg_tags!{ $($name;)*}
 
-        #[cfg(feature = "with-parser")]
+        #[cfg(feature = "with-lookup")]
         /// These are collection of svg tags that are non commonly used put together in this
         /// collection so as not to create import conflicts with the common tags
         pub const SVG_TAGS_NON_COMMON:[&'static str;5] = [$(stringify!($name),)*];
